# Krasis Benchmark Suite — 2026-02-22 16:10:16

Config: `benchmarks/qcn_1gpu_int4.toml`

| Model | Config | LGS | HCS | Prefill (tok/s) | TTFT (s) | Decode (tok/s) | ms/tok | Status | Log |
|-------|--------|----:|-----|----------------:|----------:|---------------:|-------:|--------|-----|
| Qwen3-Coder-Next | 1gpu_int4gpu_int4cpu_lgs2_nohcs | 2 | OFF | 1024.4 | 9.78 | 7.82 | 127.9 | PASS | [Qwen3-Coder-Next_native_1gpu_int4gpu_int4cpu_lgs2_nohcs.log](Qwen3-Coder-Next_native_1gpu_int4gpu_int4cpu_lgs2_nohcs.log) |
